Displaying 20 results from an estimated 33 matches for "125,13".
Did you mean:
125,19
2017 Apr 19
1
[PATCH] daemon: Remove use of fixed-size stack buffers.
...nough
(at least in theory) when using ‘-O3 -mtune=broadwell’.
---
daemon/devsparts.c | 16 +++++++++++-----
1 file changed, 11 insertions(+), 5 deletions(-)
diff --git a/daemon/devsparts.c b/daemon/devsparts.c
index 584e7d8b8..eac79197e 100644
--- a/daemon/devsparts.c
+++ b/daemon/devsparts.c
@@ -125,13 +125,16 @@ foreach_block_device (block_dev_func_t func, bool return_md)
static int
add_device (const char *device, struct stringsbuf *r)
{
- char dev_path[256];
- snprintf (dev_path, sizeof dev_path, "/dev/%s", device);
+ CLEANUP_FREE char *dev_path;
- if (add_string (r, dev_p...
2007 Jun 04
1
[LLVMdev] Patch to build on NetBSD
...il.
Index: Program.inc
===================================================================
RCS file: /var/cvs/llvm/llvm/lib/System/Unix/Program.inc,v
retrieving revision 1.24
diff -u -p -r1.24 Program.inc
--- Program.inc 23 Apr 2007 07:22:51 -0000 1.24
+++ Program.inc 4 Jun 2007 13:05:22 -0000
@@ -125,11 +125,13 @@ static void SetMemoryLimits (unsigned si
r.rlim_cur = limit;
setrlimit (RLIMIT_RSS, &r);
#endif
+#ifdef RLIMIT_AS // e.g. NetBSD doesn't have it.
// Virtual memory.
getrlimit (RLIMIT_AS, &r);
r.rlim_cur = limit;
setrlimit (RLIMIT_AS, &r);
#endif
+#...
2018 Apr 09
0
[PATCH 2/3] daemon: use the structs from the Structs module
...printf "%s%ld" device partition.Parted.part_num)
+ Some (sprintf "%s%ld" device partition.Structs.part_num)
with
| Not_found -> None
diff --git a/daemon/listfs.ml b/daemon/listfs.ml
index f6e3dcd6e..56ebadeda 100644
--- a/daemon/listfs.ml
+++ b/daemon/listfs.ml
@@ -125,13 +125,13 @@ and check_with_vfs_type device =
let default_volume = Btrfs.btrfs_subvolume_get_default mountable in
let vols =
List.filter (
- fun { Btrfs.btrfssubvolume_id = id } -> id <> default_volume
+ fun { Structs.btrfssubvolume_id = id } -> id <&g...
2018 Apr 10
0
[PATCH v2 2/5] daemon: use the structs from the Structs module
...printf "%s%ld" device partition.Parted.part_num)
+ Some (sprintf "%s%ld" device partition.Structs.part_num)
with
| Not_found -> None
diff --git a/daemon/listfs.ml b/daemon/listfs.ml
index f6e3dcd6e..56ebadeda 100644
--- a/daemon/listfs.ml
+++ b/daemon/listfs.ml
@@ -125,13 +125,13 @@ and check_with_vfs_type device =
let default_volume = Btrfs.btrfs_subvolume_get_default mountable in
let vols =
List.filter (
- fun { Btrfs.btrfssubvolume_id = id } -> id <> default_volume
+ fun { Structs.btrfssubvolume_id = id } -> id <&g...
2020 Nov 03
0
[patch V3 19/37] mm/highmem: Remove the old kmap_atomic cruft
..._atomic_prot(struct page *page, pgprot_t prot)
+static inline void *kmap_atomic(struct page *page)
{
- preempt_disable();
- pagefault_disable();
- return __kmap_local_page_prot(page, prot);
+ return kmap_atomic_prot(page, kmap_prot);
}
static inline void *kmap_atomic_pfn(unsigned long pfn)
@@ -125,13 +110,6 @@ static inline void __kunmap_atomic(void
kunmap_local_indexed(addr);
}
-#endif /* CONFIG_KMAP_LOCAL */
-
-static inline void *kmap_atomic(struct page *page)
-{
- return kmap_atomic_prot(page, kmap_prot);
-}
-
/* declarations for linux/mm/highmem.c */
unsigned int nr_free_highpage...
2017 Apr 19
2
[PATCH v2] daemon: Remove use of fixed-size stack buffers.
v1 -> v2:
- Fixes as suggested by Pino.
Rich.
2017 Apr 19
0
[PATCH v2] daemon: Remove use of fixed-size stack buffers.
...nough
(at least in theory) when using ‘-O3 -mtune=broadwell’.
---
daemon/devsparts.c | 16 +++++++++++-----
1 file changed, 11 insertions(+), 5 deletions(-)
diff --git a/daemon/devsparts.c b/daemon/devsparts.c
index 584e7d8b8..82467b92f 100644
--- a/daemon/devsparts.c
+++ b/daemon/devsparts.c
@@ -125,13 +125,16 @@ foreach_block_device (block_dev_func_t func, bool return_md)
static int
add_device (const char *device, struct stringsbuf *r)
{
- char dev_path[256];
- snprintf (dev_path, sizeof dev_path, "/dev/%s", device);
+ char *dev_path;
- if (add_string (r, dev_path) == -1) {...
2008 May 21
0
Rsync feature request
...ll terminated.
* Maximum length is len (not counting the null). */
-static int get_secret(int module, char *user, char *secret, int len)
+static int get_secret(int module, char *user, char *secret, int len,
int skip_how_many)
{
char *fname = lp_secrets_file(module);
STRUCT_STAT st;
@@ -125,8 +125,13 @@
else if (p) {
if (*p == ch)
p++;
- else if (!*p && ch == ':')
- break;
+ else if (!*p && ch == ':') {
+ if (skip_how_many == 0)
+ break;
+
+...
2017 Dec 12
2
[PATCH] df: Handle block sizes smaller than 1024 bytes (RHBZ#1525241).
...(FILE *fp,
#define MAX_LEN (LONGEST_HUMAN_READABLE > 128 ? LONGEST_HUMAN_READABLE : 128)
char buf[4][MAX_LEN];
const char *cols[4];
- int64_t factor, v;
+ int64_t v;
float percent;
const int hopts =
human_round_to_nearest|human_autoscale|human_base_1024|human_SI;
@@ -109,15 +125,13 @@ print_stat (FILE *fp,
if (!inodes) { /* 1K blocks */
if (!human) {
- factor = stat->bsize / 1024;
-
- v = stat->blocks * factor;
+ v = scale (stat->blocks, stat->bsize, 1024);
snprintf (buf[0], MAX_LEN, "%" PRIi64, v);...
2014 Nov 12
3
[PATCH v2] virtio_balloon: Convert "vballon" kthread into a workqueue
...e_head_t config_change;
-
- /* The thread servicing the balloon. */
- struct task_struct *thread;
+ /* The workqueue servicing the balloon. */
+ struct workqueue_struct *wq;
+ struct work_struct wq_work;
/* Waiting for host to ack the pages we released. */
wait_queue_head_t acked;
@@ -128,12 +125,13 @@ static void set_page_pfns(u32 pfns[], struct page *page)
static void fill_balloon(struct virtio_balloon *vb, size_t num)
{
struct balloon_dev_info *vb_dev_info = &vb->vb_dev_info;
+ size_t limit;
/* We can only do one array worth at a time. */
- num = min(num, ARRAY_SIZE(vb->...
2014 Nov 12
3
[PATCH v2] virtio_balloon: Convert "vballon" kthread into a workqueue
...e_head_t config_change;
-
- /* The thread servicing the balloon. */
- struct task_struct *thread;
+ /* The workqueue servicing the balloon. */
+ struct workqueue_struct *wq;
+ struct work_struct wq_work;
/* Waiting for host to ack the pages we released. */
wait_queue_head_t acked;
@@ -128,12 +125,13 @@ static void set_page_pfns(u32 pfns[], struct page *page)
static void fill_balloon(struct virtio_balloon *vb, size_t num)
{
struct balloon_dev_info *vb_dev_info = &vb->vb_dev_info;
+ size_t limit;
/* We can only do one array worth at a time. */
- num = min(num, ARRAY_SIZE(vb->...
2018 Nov 20
0
[PATCH v2] v2v: -o openstack: -oo verify-server-certificate=(true|false) (RHBZ#1651432).
...t-v2v [-i* options] -o openstack
[-oo server-id=SERVER]
[-oo guest-id=GUEST]
+ [-oo verify-server-certificate=false]
[-oo os-username=admin] [-oo os-*=*]
virt-v2v [-i* options] -o glance
@@ -124,6 +125,13 @@ This can be used to find disks associated with a guest, or to
associate which disks are related to which guests when converting many
guests.
+=head2 OpenStack: Ignore server certificate
+
+Using I<-oo verify-server-certificate=false> you can tell the
+openstack client to ignore the...
2005 May 31
0
[PATCH] Store page and evtchn in start_info_t
.../* Place store shared page after startinfo. */
+ vstartinfo_end = vstartinfo_start + PAGE_SIZE * 2;
vstack_start = vstartinfo_end;
vstack_end = vstack_start + PAGE_SIZE;
v_end = (vstack_end + (1<<22)-1) & ~((1<<22)-1);
@@ -125,13 +127,15 @@
" Phys-Mach map: %08lx->%08lx\n"
" Page tables: %08lx->%08lx\n"
" Start info: %08lx->%08lx\n"
+ " Store page: %08lx->%08lx\n"
" Boot stack: %08lx->%08lx\n&q...
2013 Feb 15
1
[PATCH 7/8] netback: split event channels support
.... */
- unsigned int irq;
+ /* Physical parameters of the comms window.
+ * When feature-split-event-channels = 0, tx_irq = rx_irq.
+ */
+ unsigned int tx_irq;
+ unsigned int rx_irq;
/* List of frontends to notify after a batch of frames sent. */
struct list_head notify_list;
@@ -122,10 +125,11 @@ struct xenvif *xenvif_alloc(struct device *parent,
domid_t domid,
unsigned int handle);
+/* When feature-split-event-channels == 0, tx_evtchn == rx_evtchn */
int xenvif_connect(struct xenvif *vif,
unsigned long *tx_ring_ref, unsigned int tx_ring_order,
unsigned...
2000 Dec 27
2
patch to support hurd-i386
...SSIBLE BREAKIN ATTEMPT!", name);
- strlcpy(name, ntop, sizeof name);
+ strlcpy(name, ntop, name_size);
goto check_ip_options;
}
/* Look for the address from the list of addresses. */
@@ -113,13 +125,13 @@
/* Address not found for the host name. */
log("Address %.100s maps to %.600s, but this does not map back to the address - POSSIBLE BREAKIN ATTEMPT!",
ntop, name);
- strlcpy(name, ntop,...
2009 May 29
0
[PATCH server] Add more debugging to storage tasks
...e = nil)
+ def initialize(type, name = nil, logger = nil)
@remote_pool = nil
@build_on_start = true
@remote_pool_defined = false
@remote_pool_started = false
+ @logger = logger
if name == nil
@name = type + "-" + String.random_alphanumeric
@@ -124,11 +125,13 @@ class LibvirtPool
xml_desc = result.description
if self.xmlequal?(Document.new(xml_desc).root)
@remote_pool = pool
+ @logger.debug("Found existing storage pool #{pool.name} on host: #{node.hostname}")
break
end
end
if @remote...
2018 Nov 20
3
[PATCH v4 0/2] v2v: -o openstack: -oo verify-server-certificate=(true|false) (RHBZ#1651432).
The first patch restricts passthrough parameters to ones matching
"os-*". This was how it was documented, but not how it was
implemented.
The second patch is the same as v2 here:
https://www.redhat.com/archives/libguestfs/2018-November/msg00187.html
Rich.
2008 Oct 23
2
[PATCH 1/1] OCFS2: fix for nfs getting stale inode.
...e_bast_func(void *opaque,
int level);
+static void ocfs2_dealloc_ast_func(void *opaque);
+static void ocfs2_dealloc_bast_func(void *opaquei,
+ int level);
/* so far, all locks have gotten along with the same unlock ast */
static void ocfs2_unlock_ast_func(void *opaque,
@@ -122,6 +125,13 @@ static struct ocfs2_lock_res_ops ocfs2_r
.unblock = ocfs2_unblock_osb_lock,
};
+static struct ocfs2_lock_res_ops ocfs2_dealloc_lops = {
+ .ast = ocfs2_dealloc_ast_func,
+ .bast = ocfs2_dealloc_bast_func,
+ .unlock_ast = ocfs2_unlock_ast_func,
+ .unblock = ocfs2_unblock_osb_lock,
+};
+...
2014 Nov 12
0
[PATCH v2] virtio_balloon: Convert "vballon" kthread into a workqueue
...use system_freezable_wq instead.
I do agree a dedicated wq is better since this can get blocked
for a long time while allocating memory.
However, please add a comment to this effect.
>
> /* Waiting for host to ack the pages we released. */
> wait_queue_head_t acked;
> @@ -128,12 +125,13 @@ static void set_page_pfns(u32 pfns[], struct page *page)
> static void fill_balloon(struct virtio_balloon *vb, size_t num)
> {
> struct balloon_dev_info *vb_dev_info = &vb->vb_dev_info;
> + size_t limit;
>
> /* We can only do one array worth at a time. */
>...
2018 Apr 09
5
[PATCH 0/3] daemon: generate almost all the API OCaml interfaces
Hi,
as a followup for the signature fix for mount_vfs [1], here it is a
patch series to generate automatically most of the OCaml interfaces of
daemon actions. Only the Lvm and Mount modules are left with
hand-written interfaces.
[1] https://www.redhat.com/archives/libguestfs/2018-April/msg00059.html
Thanks,
Pino Toscano (3):
daemon: directly use Optgroups
daemon: use the structs from the